package com.hzya.frame.plugin.lets.plugin.base;

import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.base.PluginBaseEntity;
import com.hzya.frame.plugin.lets.ofsvo.QueryOfsSKURequestVO;
import com.hzya.frame.plugin.lets.util.PushDataByU8cUtil;
import com.hzya.frame.plugin.lets.util.SaveOrUpdateBusinessLogUtil;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.dao.IIntegrationTaskLivingDetailsDao;
import com.hzya.frame.ttxofs.basics.ReturnMessageBasics;
import com.hzya.frame.ttxofs.dto.InterfaceParamByU8CApiDto;
import com.hzya.frame.ttxofs.service.OfsUnifiedService;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.Date;
import java.util.concurrent.locks.ReentrantLock;

/**
 * OFS->U8C货品档案 新增，修改，删除
 * add by zyd 20240802
 *
 * 存货基本档案新增     /u8cloud/api/uapbd/invbasdoc/insert
 * 存货基本档案修改     /u8cloud/api/uapbd/invbasdoc/update
 * 存货基本档案封存     /u8cloud/api/uapbd/invbasdoc/seal
 * 存货基本档案取消封存  /u8cloud/api/uapbd/invbasdoc/unseal
 */
public class SKUPluginInitializer extends PluginBaseEntity {

    Logger logger = LoggerFactory.getLogger(SKUPluginInitializer.class);

    private static final ReentrantLock LOCK = new ReentrantLock(true);

    @Override
    public void initialize() {
        logger.info(getPluginLabel() + "執行初始化方法initialize()");
    }

    @Override
    public void destroy() {
        logger.info(getPluginLabel() + "執行銷毀方法destroy()");
    }

    @Override
    public String getPluginId() {
        return "com.hzya.frame.plugin.lets.plugin.base.GoodsPluginInitializer";
    }

    @Override
    public String getPluginName() {
        return "丽知：OFS货品档案--->U8C货品档案";
    }

    @Override
    public String getPluginLabel() {
        return "丽知：OFS货品档案--->U8C货品档案";
    }

    @Override
    public String getPluginType() {
        return "1";
    }

    @Autowired
    private IIntegrationTaskLivingDetailsDao iIntegrationTaskLivingDetailsDao;
    @Autowired
    private PushDataByU8cUtil pushDataByU8cUtil;
    @Autowired
    private SaveOrUpdateBusinessLogUtil saveOrUpdateBusinessLogUtil;

    @Autowired
    private OfsUnifiedService ofsUnifiedService;
    @Override
    public JsonResultEntity executeBusiness(JSONObject requestJson) throws Exception {
        return null;
    }


    /**
     * 默认推送
     */
    public void start() {
        try {
            //获取当前时间
            Date currentDate = new Date();
            Date startTime = DateUtil.offset(currentDate, DateField.MINUTE, -10);
            Date endTime = DateUtil.offset(currentDate, DateField.MINUTE, -2);
            String startTimeStr = DateUtil.format(startTime, "yyyy-MM-dd HH:mm:ss");
            String endTimeStr = DateUtil.format(endTime, "yyyy-MM-dd HH:mm:ss");

            QueryOfsSKURequestVO queryOfsSKURequestVO = new QueryOfsSKURequestVO();
//            queryOfsSKURequestVO.setCreated_start(startTimeStr);
//            queryOfsSKURequestVO.setCreated_end(endTimeStr);
//            queryOfsSKURequestVO.setCreated_start("2023-10-15 00:00:00");
//            queryOfsSKURequestVO.setCreated_end("2023-10-21 23:59:59");
//            queryOfsSKURequestVO.setCompanyCode("");
            queryOfsSKURequestVO.setPageNo(1);
            queryOfsSKURequestVO.setPageSize(500);
            queryOfsSKUs(queryOfsSKURequestVO);





        } catch (Exception e) {
            logger.error("丽知：OFS货品档案--->U8C货品档案,start()方法报错：", e);
        }
    }

    /**
     * 按分类名称
     */
    public void start(String goodsName) {
        try {
            QueryOfsSKURequestVO queryOfsGoodsRequestVO = new QueryOfsSKURequestVO();


        } catch (Exception e) {
            logger.error("丽知：丽知：OFS货品档案--->U8C货品档案,start(String goodsName)方法报错：", e);
        }

    }

    /**
     * 按时间区间
     */
    public void start(String startTime, String endTime) {
        try {
            Date business_start = DateUtil.parse(startTime);
            Date business_end = DateUtil.parse(endTime);
            String start = DateUtil.format(business_start, "yyyy-MM-dd") + " 00:00:00";
            String end = DateUtil.format(business_end, "yyyy-MM-dd") + " 23:59:59";
        } catch (Exception e) {
            logger.error("丽知：丽知：OFS货品档案--->U8C货品档案,start(String startTime, String endTime)方法报错：", e);
        }
    }

    /**
     * 查询OFS SKU档案
     */
    public void queryOfsSKUs(QueryOfsSKURequestVO queryOfsGoodsRequestVO) throws Exception {
        InterfaceParamByU8CApiDto interfaceParamDto = new InterfaceParamByU8CApiDto();
        interfaceParamDto.setApi("ofs.sku.search");
        queryOfsGoodsRequestVO.setClientCode("LETS");
        interfaceParamDto.setData(JSON.toJSONString(queryOfsGoodsRequestVO));
        ReturnMessageBasics returnMessageBasics = ofsUnifiedService.unifiedByU8CApi(interfaceParamDto);

    }



}
